@@ -111,7 +111,7 @@ install() {
   if [ -f ${instdir}${prefix}/share/info/dir ] ; then \
     rm ${instdir}${prefix}/share/info/dir ; \
   fi && \
-  for dirn in ${prefix}/doc/Cygwin ${prefix}/doc/${PKG}-${VER} \
+  for dirn in ${prefix}/share/doc/Cygwin ${prefix}/share/doc/${PKG}-${VER} \
               ${sysconfdir}/postinstall ${sysconfdir}/profile.d ; do \
     if [ ! -d ${instdir}${dirn} ]; then \
       mkdir -p ${instdir}${dirn} ; \
@@ -126,11 +126,11 @@ install() {
   done && \
   if [ ! "x$templist" = "x" ]; then \
     /usr/bin/install -c -m 644 $templist \
-         ${instdir}${prefix}/doc/${PKG}-${VER} ; \
+         ${instdir}${prefix}/share/doc/${PKG}-${VER} ; \
   fi && \
   echo "Copying example Functions and StartupFiles" && \
-  cp -ar ${srcdir}/Functions ${instdir}${prefix}/doc/${PKG}-${VER} && \
-  cp -ar ${srcdir}/StartupFiles ${instdir}${prefix}/doc/${PKG}-${VER} && \
+  cp -ar ${srcdir}/Functions ${instdir}${prefix}/share/doc/${PKG}-${VER} && \
+  cp -ar ${srcdir}/StartupFiles ${instdir}${prefix}/share/doc/${PKG}-${VER} && \
   templist=""; \
   for f in ${srcdir}/CYGWIN-PATCHES/zprofile ${srcdir}/CYGWIN-PATCHES/zlogin \
            ${srcdir}/CYGWIN-PATCHES/zlogout ${srcdir}/CYGWIN-PATCHES/zshenv \
@@ -144,7 +144,7 @@ install() {
   done && \
   if [ ! "x$templist" = "x" ]; then \
     /usr/bin/install -c -m 644 $templist \
-         ${instdir}${prefix}/doc/${PKG}-${VER}/StartupFiles ; \
+         ${instdir}${prefix}/share/doc/${PKG}-${VER}/StartupFiles ; \
   fi && \
   /usr/bin/install -c -m 755 ${srcdir}/CYGWIN-PATCHES/mkzsh \
     ${instdir}${prefix}/bin && \
@@ -154,11 +154,11 @@ install() {
     ${instdir}${sysconfdir}/postinstall/${PKG}.sh && \
   echo "Generating ${PKG}-${VER}.README" && \
   /usr/bin/install -c -m 644 ${srcdir}/CYGWIN-PATCHES/${PKG}.README \
-    ${instdir}${prefix}/doc/Cygwin/${PKG}-${VER}.README && \
+    ${instdir}${prefix}/share/doc/Cygwin/${PKG}-${VER}.README && \
   (cd ${instdir} && \
   (find . -type f | sort | sed 's/^\./  /' > /tmp/.inst.lis) && \
   sed -f ${srcdir}/CYGWIN-PATCHES/${PKG}.README.sed < ${srcdir}/CYGWIN-PATCHES/${PKG}.README > /tmp/.inst.README && \
-  /usr/bin/install -c -m 644 /tmp/.inst.README ${instdir}${prefix}/doc/Cygwin/${PKG}-${VER}.README && \
+  /usr/bin/install -c -m 644 /tmp/.inst.README ${instdir}${prefix}/share/doc/Cygwin/${PKG}-${VER}.README && \
   rm -f /tmp/.inst.lis /tmp/.inst.README ) )
 }
 mkpatch() {
